# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proxy_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12proxy_common.proto\x12\x17\x64ingodb.pb.proxy.common\"\xbe\x01\n\x10\x43olumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sql_type\x18\x02 \x01(\t\x12\x14\n\x0c\x65lement_type\x18\x03 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\r\n\x05scale\x18\x05 \x01(\x05\x12\x10\n\x08nullable\x18\x06 \x01(\x08\x12\x12\n\nindexOfKey\x18\x07 \x01(\x05\x12\x17\n\x0fhas_default_val\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65\x66\x61ult_val\x18\t \x01(\t\"\x80\x01\n\x06Vector\x12\x11\n\tdimension\x18\x01 \x01(\x05\x12\x36\n\nvalue_type\x18\x02 \x01(\x0e\x32\".dingodb.pb.proxy.common.ValueType\x12\x14\n\x0c\x66loat_values\x18\x03 \x03(\x02\x12\x15\n\rbinary_values\x18\x04 \x03(\x0c\"\xbb\x01\n\x10VectorScalarData\x12N\n\x0bscalar_data\x18\x01 \x03(\x0b\x32\x39.dingodb.pb.proxy.common.VectorScalarData.ScalarDataEntry\x1aW\n\x0fScalarDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.dingodb.pb.proxy.common.ScalarValue:\x02\x38\x01\"9\n\x0fVectorTableData\x12\x11\n\ttable_key\x18\x01 \x01(\x0c\x12\x13\n\x0btable_value\x18\x02 \x01(\x0c\"\xc9\x01\n\x0cVectorWithId\x12\n\n\x02id\x18\x01 \x01(\x04\x12/\n\x06vector\x18\x02 \x01(\x0b\x32\x1f.dingodb.pb.proxy.common.Vector\x12>\n\x0bscalar_data\x18\x03 \x01(\x0b\x32).dingodb.pb.proxy.common.VectorScalarData\x12<\n\ntable_data\x18\x04 \x01(\x0b\x32(.dingodb.pb.proxy.common.VectorTableData\"\x9f\x01\n\x12VectorWithDistance\x12=\n\x0evector_with_id\x18\x01 \x01(\x0b\x32%.dingodb.pb.proxy.common.VectorWithId\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\x12\x38\n\x0bmetric_type\x18\x03 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\"\xe6\x01\n\x0eIndexParameter\x12\x36\n\nindex_type\x18\x01 \x01(\x0e\x32\".dingodb.pb.proxy.common.IndexType\x12M\n\x16vector_index_parameter\x18\x02 \x01(\x0b\x32-.dingodb.pb.proxy.common.VectorIndexParameter\x12M\n\x16scalar_index_parameter\x18\x03 \x01(\x0b\x32-.dingodb.pb.proxy.common.ScalarIndexParameter\"^\n\x0f\x43reateFlatParam\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x38\n\x0bmetric_type\x18\x02 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\"u\n\x12\x43reateIvfFlatParam\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x38\n\x0bmetric_type\x18\x02 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\x12\x12\n\nncentroids\x18\x03 \x01(\x05\"\xba\x01\n\x10\x43reateIvfPqParam\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x38\n\x0bmetric_type\x18\x02 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\x12\x12\n\nncentroids\x18\x03 \x01(\x05\x12\x12\n\nnsubvector\x18\x04 \x01(\x05\x12\x18\n\x10\x62ucket_init_size\x18\x05 \x01(\x05\x12\x17\n\x0f\x62ucket_max_size\x18\x06 \x01(\x05\"\x9c\x01\n\x0f\x43reateHnswParam\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x38\n\x0bmetric_type\x18\x02 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\x12\x16\n\x0e\x65\x66\x43onstruction\x18\x03 \x01(\r\x12\x14\n\x0cmax_elements\x18\x04 \x01(\r\x12\x0e\n\x06nlinks\x18\x05 \x01(\x05\"\xa0\x01\n\x12\x43reateDiskAnnParam\x12\x11\n\tdimension\x18\x01 \x01(\r\x12\x38\n\x0bmetric_type\x18\x02 \x01(\x0e\x32#.dingodb.pb.proxy.common.MetricType\x12\x11\n\tnum_trees\x18\x03 \x01(\x05\x12\x15\n\rnum_neighbors\x18\x04 \x01(\x05\x12\x13\n\x0bnum_threads\x18\x05 \x01(\x05\"\xd9\x03\n\x14VectorIndexParameter\x12\x43\n\x11vector_index_type\x18\x01 \x01(\x0e\x32(.dingodb.pb.proxy.common.VectorIndexType\x12\x42\n\x0e\x66lat_parameter\x18\x02 \x01(\x0b\x32(.dingodb.pb.proxy.common.CreateFlatParamH\x00\x12I\n\x12ivf_flat_parameter\x18\x03 \x01(\x0b\x32+.dingodb.pb.proxy.common.CreateIvfFlatParamH\x00\x12\x45\n\x10ivf_pq_parameter\x18\x04 \x01(\x0b\x32).dingodb.pb.proxy.common.CreateIvfPqParamH\x00\x12\x42\n\x0ehnsw_parameter\x18\x05 \x01(\x0b\x32(.dingodb.pb.proxy.common.CreateHnswParamH\x00\x12H\n\x11\x64iskann_parameter\x18\x06 \x01(\x0b\x32+.dingodb.pb.proxy.common.CreateDiskAnnParamH\x00\x42\x18\n\x16vector_index_parameter\"\xc8\x01\n\x0cVectorSchema\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.dingodb.pb.proxy.common.VectorSchema.Type\x12\x0e\n\x06is_key\x18\x02 \x01(\x08\x12\x13\n\x0bis_nullable\x18\x03 \x01(\x08\x12\r\n\x05index\x18\x04 \x01(\x05\"J\n\x04Type\x12\x08\n\x04\x42OOL\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x08\n\x04LONG\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x12\n\n\x06STRING\x10\x05\"[\n\x14ScalarIndexParameter\x12\x43\n\x11scalar_index_type\x18\x01 \x01(\x0e\x32(.dingodb.pb.proxy.common.ScalarIndexType\".\n\x0fSearchFlatParam\x12\x1b\n\x13parallel_on_queries\x18\x01 \x01(\x05\"A\n\x12SearchIvfFlatParam\x12\x0e\n\x06nprobe\x18\x01 \x01(\x05\x12\x1b\n\x13parallel_on_queries\x18\x02 \x01(\x05\"S\n\x10SearchIvfPqParam\x12\x0e\n\x06nprobe\x18\x01 \x01(\x05\x12\x1b\n\x13parallel_on_queries\x18\x02 \x01(\x05\x12\x12\n\nrecall_num\x18\x03 \x01(\x05\"#\n\x0fSearchHNSWParam\x12\x10\n\x08\x65\x66Search\x18\x01 \x01(\x05\"\x14\n\x12SearchDiskAnnParam\"\xc6\x05\n\x15VectorSearchParameter\x12\r\n\x05top_n\x18\x01 \x01(\r\x12\x1c\n\x14with_out_vector_data\x18\x02 \x01(\x08\x12\x18\n\x10with_scalar_data\x18\x03 \x01(\x08\x12\x15\n\rselected_keys\x18\x04 \x03(\t\x12\x17\n\x0fwith_table_data\x18\x05 \x01(\x08\x12\x38\n\x04\x66lat\x18\x0b \x01(\x0b\x32(.dingodb.pb.proxy.common.SearchFlatParamH\x00\x12?\n\x08ivf_flat\x18\x0c \x01(\x0b\x32+.dingodb.pb.proxy.common.SearchIvfFlatParamH\x00\x12;\n\x06ivf_pq\x18\r \x01(\x0b\x32).dingodb.pb.proxy.common.SearchIvfPqParamH\x00\x12\x38\n\x04hnsw\x18\x0e \x01(\x0b\x32(.dingodb.pb.proxy.common.SearchHNSWParamH\x00\x12>\n\x07\x64iskann\x18\x0f \x01(\x0b\x32+.dingodb.pb.proxy.common.SearchDiskAnnParamH\x00\x12\x19\n\x11use_scalar_filter\x18\x14 \x01(\x08\x12<\n\rvector_filter\x18\x15 \x01(\x0e\x32%.dingodb.pb.proxy.common.VectorFilter\x12\x45\n\x12vector_filter_type\x18\x16 \x01(\x0e\x32).dingodb.pb.proxy.common.VectorFilterType\x12\x46\n\x12vector_coprocessor\x18\x17 \x01(\x0b\x32*.dingodb.pb.proxy.common.VectorCoprocessor\x12\x12\n\nvector_ids\x18\x18 \x03(\x04\x42\x08\n\x06search\"\xa1\x01\n\x11VectorCoprocessor\x12\x16\n\x0eschema_version\x18\x01 \x01(\x05\x12\x45\n\x0foriginal_schema\x18\x02 \x01(\x0b\x32,.dingodb.pb.proxy.common.VectorSchemaWrapper\x12\x19\n\x11selection_columns\x18\x03 \x03(\x05\x12\x12\n\nexpression\x18\x04 \x01(\x0c\"c\n\x13VectorSchemaWrapper\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).dingodb.pb.proxy.common.ColumnDefinition\x12\x11\n\tcommon_id\x18\x02 \x01(\x03\"\xad\x01\n\x0bScalarField\x12\x13\n\tbool_data\x18\x01 \x01(\x08H\x00\x12\x12\n\x08int_data\x18\x02 \x01(\x05H\x00\x12\x13\n\tlong_data\x18\x03 \x01(\x03H\x00\x12\x14\n\nfloat_data\x18\x04 \x01(\x02H\x00\x12\x15\n\x0b\x64ouble_data\x18\x05 \x01(\x01H\x00\x12\x15\n\x0bstring_data\x18\x06 \x01(\tH\x00\x12\x14\n\nbytes_data\x18\x07 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x81\x01\n\x0bScalarValue\x12<\n\nfield_type\x18\x01 \x01(\x0e\x32(.dingodb.pb.proxy.common.ScalarFieldType\x12\x34\n\x06\x66ields\x18\x02 \x03(\x0b\x32$.dingodb.pb.proxy.common.ScalarField\"\xbd\x01\n\x12VectorIndexMetrics\x12\x43\n\x11vector_index_type\x18\x01 \x01(\x0e\x32(.dingodb.pb.proxy.common.VectorIndexType\x12\x15\n\rcurrent_count\x18\x02 \x01(\x03\x12\x15\n\rdeleted_count\x18\x03 \x01(\x03\x12\x0e\n\x06max_id\x18\x04 \x01(\x03\x12\x0e\n\x06min_id\x18\x05 \x01(\x03\x12\x14\n\x0cmemory_bytes\x18\x06 \x01(\x03*!\n\tValueType\x12\t\n\x05\x46LOAT\x10\x00\x12\t\n\x05UINT8\x10\x01*e\n\x0fScalarIndexType\x12\x1a\n\x16SCALAR_INDEX_TYPE_NONE\x10\x00\x12\x19\n\x15SCALAR_INDEX_TYPE_LSM\x10\x01\x12\x1b\n\x17SCALAR_INDEX_TYPE_BTREE\x10\x02*N\n\tIndexType\x12\x13\n\x0fINDEX_TYPE_NONE\x10\x00\x12\x15\n\x11INDEX_TYPE_VECTOR\x10\x01\x12\x15\n\x11INDEX_TYPE_SCALAR\x10\x02*\xc2\x01\n\x0fVectorIndexType\x12\x1a\n\x16VECTOR_INDEX_TYPE_NONE\x10\x00\x12\x1a\n\x16VECTOR_INDEX_TYPE_FLAT\x10\x01\x12\x1e\n\x1aVECTOR_INDEX_TYPE_IVF_FLAT\x10\x02\x12\x1c\n\x18VECTOR_INDEX_TYPE_IVF_PQ\x10\x03\x12\x1a\n\x16VECTOR_INDEX_TYPE_HNSW\x10\x04\x12\x1d\n\x19VECTOR_INDEX_TYPE_DISKANN\x10\x05*m\n\nMetricType\x12\x14\n\x10METRIC_TYPE_NONE\x10\x00\x12\x12\n\x0eMETRIC_TYPE_L2\x10\x01\x12\x1d\n\x19METRIC_TYPE_INNER_PRODUCT\x10\x02\x12\x16\n\x12METRIC_TYPE_COSINE\x10\x03*I\n\x0cVectorFilter\x12\x11\n\rSCALAR_FILTER\x10\x00\x12\x10\n\x0cTABLE_FILTER\x10\x01\x12\x14\n\x10VECTOR_ID_FILTER\x10\n*1\n\x10VectorFilterType\x12\x0e\n\nQUERY_POST\x10\x00\x12\r\n\tQUERY_PRE\x10\x01*\x80\x01\n\x0fScalarFieldType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04INT8\x10\x02\x12\t\n\x05INT16\x10\x03\x12\t\n\x05INT32\x10\x04\x12\t\n\x05INT64\x10\x05\x12\x0b\n\x07\x46LOAT32\x10\x06\x12\n\n\x06\x44OUBLE\x10\x07\x12\n\n\x06STRING\x10\x08\x12\t\n\x05\x42YTES\x10\tB\x1c\n\x17io.dingodb.proxy.common\x88\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proxy_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027io.dingodb.proxy.common\210\001\001'
  _VECTORSCALARDATA_SCALARDATAENTRY._options = None
  _VECTORSCALARDATA_SCALARDATAENTRY._serialized_options = b'8\001'
  _globals['_VALUETYPE']._serialized_start=4454
  _globals['_VALUETYPE']._serialized_end=4487
  _globals['_SCALARINDEXTYPE']._serialized_start=4489
  _globals['_SCALARINDEXTYPE']._serialized_end=4590
  _globals['_INDEXTYPE']._serialized_start=4592
  _globals['_INDEXTYPE']._serialized_end=4670
  _globals['_VECTORINDEXTYPE']._serialized_start=4673
  _globals['_VECTORINDEXTYPE']._serialized_end=4867
  _globals['_METRICTYPE']._serialized_start=4869
  _globals['_METRICTYPE']._serialized_end=4978
  _globals['_VECTORFILTER']._serialized_start=4980
  _globals['_VECTORFILTER']._serialized_end=5053
  _globals['_VECTORFILTERTYPE']._serialized_start=5055
  _globals['_VECTORFILTERTYPE']._serialized_end=5104
  _globals['_SCALARFIELDTYPE']._serialized_start=5107
  _globals['_SCALARFIELDTYPE']._serialized_end=5235
  _globals['_COLUMNDEFINITION']._serialized_start=48
  _globals['_COLUMNDEFINITION']._serialized_end=238
  _globals['_VECTOR']._serialized_start=241
  _globals['_VECTOR']._serialized_end=369
  _globals['_VECTORSCALARDATA']._serialized_start=372
  _globals['_VECTORSCALARDATA']._serialized_end=559
  _globals['_VECTORSCALARDATA_SCALARDATAENTRY']._serialized_start=472
  _globals['_VECTORSCALARDATA_SCALARDATAENTRY']._serialized_end=559
  _globals['_VECTORTABLEDATA']._serialized_start=561
  _globals['_VECTORTABLEDATA']._serialized_end=618
  _globals['_VECTORWITHID']._serialized_start=621
  _globals['_VECTORWITHID']._serialized_end=822
  _globals['_VECTORWITHDISTANCE']._serialized_start=825
  _globals['_VECTORWITHDISTANCE']._serialized_end=984
  _globals['_INDEXPARAMETER']._serialized_start=987
  _globals['_INDEXPARAMETER']._serialized_end=1217
  _globals['_CREATEFLATPARAM']._serialized_start=1219
  _globals['_CREATEFLATPARAM']._serialized_end=1313
  _globals['_CREATEIVFFLATPARAM']._serialized_start=1315
  _globals['_CREATEIVFFLATPARAM']._serialized_end=1432
  _globals['_CREATEIVFPQPARAM']._serialized_start=1435
  _globals['_CREATEIVFPQPARAM']._serialized_end=1621
  _globals['_CREATEHNSWPARAM']._serialized_start=1624
  _globals['_CREATEHNSWPARAM']._serialized_end=1780
  _globals['_CREATEDISKANNPARAM']._serialized_start=1783
  _globals['_CREATEDISKANNPARAM']._serialized_end=1943
  _globals['_VECTORINDEXPARAMETER']._serialized_start=1946
  _globals['_VECTORINDEXPARAMETER']._serialized_end=2419
  _globals['_VECTORSCHEMA']._serialized_start=2422
  _globals['_VECTORSCHEMA']._serialized_end=2622
  _globals['_VECTORSCHEMA_TYPE']._serialized_start=2548
  _globals['_VECTORSCHEMA_TYPE']._serialized_end=2622
  _globals['_SCALARINDEXPARAMETER']._serialized_start=2624
  _globals['_SCALARINDEXPARAMETER']._serialized_end=2715
  _globals['_SEARCHFLATPARAM']._serialized_start=2717
  _globals['_SEARCHFLATPARAM']._serialized_end=2763
  _globals['_SEARCHIVFFLATPARAM']._serialized_start=2765
  _globals['_SEARCHIVFFLATPARAM']._serialized_end=2830
  _globals['_SEARCHIVFPQPARAM']._serialized_start=2832
  _globals['_SEARCHIVFPQPARAM']._serialized_end=2915
  _globals['_SEARCHHNSWPARAM']._serialized_start=2917
  _globals['_SEARCHHNSWPARAM']._serialized_end=2952
  _globals['_SEARCHDISKANNPARAM']._serialized_start=2954
  _globals['_SEARCHDISKANNPARAM']._serialized_end=2974
  _globals['_VECTORSEARCHPARAMETER']._serialized_start=2977
  _globals['_VECTORSEARCHPARAMETER']._serialized_end=3687
  _globals['_VECTORCOPROCESSOR']._serialized_start=3690
  _globals['_VECTORCOPROCESSOR']._serialized_end=3851
  _globals['_VECTORSCHEMAWRAPPER']._serialized_start=3853
  _globals['_VECTORSCHEMAWRAPPER']._serialized_end=3952
  _globals['_SCALARFIELD']._serialized_start=3955
  _globals['_SCALARFIELD']._serialized_end=4128
  _globals['_SCALARVALUE']._serialized_start=4131
  _globals['_SCALARVALUE']._serialized_end=4260
  _globals['_VECTORINDEXMETRICS']._serialized_start=4263
  _globals['_VECTORINDEXMETRICS']._serialized_end=4452
# @@protoc_insertion_point(module_scope)
